# GenomicsDB-Python

Experimental Python Bindings to the native [GenomicsDB](https://github.com/GenomicsDB/GenomicsDB) library

## Installation
Install `genomicsdb` by running
```
pip install genomicsdb
```

